@@ -1,7 +1,11 @@
 #!/bin/bash
 #%stage: boot
 #%depends: start dm
-#%programs: /sbin/udevd /sbin/udevadm /bin/uname
+#%programs: blkid
+#%programs: sg_inq
+#%programs: udevadm
+#%programs: udevd
+#%programs: uname
 #%dontshow
 #
 ##### udev initialization
@@ -14,7 +18,7 @@
 ##
 
 wait_for_events() {
-    /sbin/udevadm settle --timeout=$udev_timeout
+    udevadm settle --timeout=$udev_timeout
 }
 
 # Check for debugging
@@ -26,6 +30,7 @@ fi
 
 # Start udev
 echo "Creating device nodes with udev"
-/sbin/udevd --daemon
-/sbin/udevadm trigger --action=add
+udevd --daemon
+udevadm trigger --action=add
+udevadm trigger --type=subsystems --action=add
 wait_for_events
