@@ -21,18 +21,20 @@ if [ -x /sbin/dmsetup ]; then
 	# Add all dm modules
 	dm_modules=
 	for table in $(dmsetup table | cut -f 4 -d ' ' | sort | uniq); do
-	    if [ "$table" ] && [ "$table" != "linear" ] && [ "$table" != "striped" ] ; then
+	    if [ "$table" ] && [ "$table" != "linear" ] &&
+	       [ "$table" != "striped" ] && [ "$table" != "snapshot-origin" ] ; then
 		dm_modules="$dm_modules dm-$table"
 	    fi
 	done
     fi
 
     # include dm block var from sysconfig
-    mkdir -p etc/sysconfig
-    grep DM_BLOCK /etc/sysconfig/kernel > etc/sysconfig/kernel
-	mkdir -p lib/udev/rules.d
-	cp /lib/udev/rules.d/10-dm.rules lib/udev/rules.d
-	cp /lib/udev/rules.d/13-dm-disk.rules lib/udev/rules.d
-	cp /lib/udev/rules.d/95-dm-notify.rules lib/udev/rules.d
+    mkdir -p $tmp_mnt/etc/sysconfig
+    grep DM_BLOCK /etc/sysconfig/kernel > $tmp_mnt/etc/sysconfig/kernel
+    mkdir -p $tmp_mnt/usr/lib/udev/rules.d
+    cp /usr/lib/udev/rules.d/10-dm.rules $tmp_mnt/usr/lib/udev/rules.d/
+    cp /usr/lib/udev/rules.d/13-dm-disk.rules $tmp_mnt/usr/lib/udev/rules.d
+    cp /usr/lib/udev/rules.d/95-dm-notify.rules $tmp_mnt/usr/lib/udev/rules.d
     save_var root_dm
+    save_var dm_modules
 fi
