@@ -5,8 +5,8 @@ BEGIN {
         new => ["function", "any", "string"],
         swig_destructive_get => ["function", "boolean", "any"],
         swig_destructive_set => ["function", "void", "any", "boolean"],
-        swig_actions_get => ["function", ["list", "string"], "any"],
-        swig_actions_set => ["function", "void", "any", ["list", "string"]],
+        swig_text_get => ["function", "string", "any"],
+        swig_text_set => ["function", "void", "any", "string"],
     );
 }
 
