@@ -17,6 +17,8 @@ BEGIN {
         swig_sectorSize_set => ["function", "void", "any", "integer"],
         swig_disklabel_get => ["function", "string", "any"],
         swig_disklabel_set => ["function", "void", "any", "string"],
+        swig_orig_disklabel_get => ["function", "string", "any"],
+        swig_orig_disklabel_set => ["function", "void", "any", "string"],
         swig_maxPrimary_get => ["function", "integer", "any"],
         swig_maxPrimary_set => ["function", "void", "any", "integer"],
         swig_extendedPossible_get => ["function", "boolean", "any"],
@@ -27,6 +29,8 @@ BEGIN {
         swig_initDisk_set => ["function", "void", "any", "boolean"],
         swig_transport_get => ["function", "integer", "any"],
         swig_transport_set => ["function", "void", "any", "integer"],
+        swig_has_fake_partition_get => ["function", "boolean", "any"],
+        swig_has_fake_partition_set => ["function", "void", "any", "boolean"],
         swig_iscsi_get => ["function", "boolean", "any"],
         swig_iscsi_set => ["function", "void", "any", "boolean"],
     );
