@@ -5,10 +5,10 @@ BEGIN {
         new => ["function", "any", "string"],
         swig_v_get => ["function", "any", "any"],
         swig_v_set => ["function", "void", "any", "any"],
-        swig_stripe_get => ["function", "integer", "any"],
-        swig_stripe_set => ["function", "void", "any", "integer"],
-        swig_stripe_size_get => ["function", "integer", "any"],
-        swig_stripe_size_set => ["function", "void", "any", "integer"],
+        swig_stripes_get => ["function", "integer", "any"],
+        swig_stripes_set => ["function", "void", "any", "integer"],
+        swig_stripeSizeK_get => ["function", "integer", "any"],
+        swig_stripeSizeK_set => ["function", "void", "any", "integer"],
         swig_uuid_get => ["function", "string", "any"],
         swig_uuid_set => ["function", "void", "any", "string"],
         swig_status_get => ["function", "string", "any"],
@@ -21,8 +21,10 @@ BEGIN {
         swig_dm_target_set => ["function", "void", "any", "string"],
         swig_origin_get => ["function", "string", "any"],
         swig_origin_set => ["function", "void", "any", "string"],
-        swig_sizeK_get => ["function", "integer", "any"],
-        swig_sizeK_set => ["function", "void", "any", "integer"],
+        swig_used_pool_get => ["function", "string", "any"],
+        swig_used_pool_set => ["function", "void", "any", "string"],
+        swig_pool_get => ["function", "boolean", "any"],
+        swig_pool_set => ["function", "void", "any", "boolean"],
     );
 }
 
